/* PORTS
 *
 * B0 - serial out
 * C0 - clock
 */

#define F_CPU	1000000

#include <avr/io.h>
#include <util/delay.h>

void spi_send(unsigned char val);

int main(void)
{
	/* MOSI and SCK outputs */
	DDRB = 0xff;

	setup_adc();

	/* enable SPI, master, clock/16, setup-falling, sample-rising */
	SPCR = (1 << SPE) | (1 << MSTR) | (1 << SPR0) | (1 << CPOL) | (1 << CPHA);

	for(;;) {
		spi_send(ADCH);
		_delay_ms(25);
	}
	return 0;
}

void setup_adc(void)
{
	/* disable digital input buffers on ADC pins */
	DIDR0 = 0x3f;

	/* - disable internal reference values (use Aref)
	 * - set left-adjustment
	 * - and select ADC0
	 */
	ADMUX = 1 << ADLAR;

	/* - enable ADC
	 * - set prescaler value to 3 (clock/8)
	 * - set auto trigger enable
	 */
	ADCSRA = (1 << ADEN) | (3 << ADPS0) | (1 << ADATE);

	/* select ADIF (interrupt flag) as the trigger source */
	ADCSRB = 0;

	/* start conversion */
	ADCSRA |= (1 << ADSC);
}


void delay(void)
{
	int i;
	for(i=0; i<1000; i++) {
		asm volatile("nop");
	}
}

void spi_send(unsigned char val)
{
	SPDR = val;
	while(!(SPSR & (1 << SPIF)));
}
